@@ -1,5 +1,5 @@
 #
-# $Id: test.pl,v 1.12 2002/04/27 11:21:44 evilio Exp $
+# $Id: test.pl,v 1.13 2002/05/01 11:30:13 evilio Exp $
 #
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
@@ -9,7 +9,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $max = 11; $| = 1; print "1..$max\n"; }
+BEGIN { $max = 13; $| = 1; print "1..$max\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use CGI;
 use DBI;
@@ -110,7 +110,8 @@ if ( $ENV{DBIX_BROWSE_MAKE_TEST} && $ENV{DBI_DSN} ) {
     ok(); # 12
 }
 else {
-    print "Skipping DBI tests (2..$max) on this platform.\n";
+    print "Skipping DBI tests (2..$max) on this environment.\n";
+    print "To perform all tests, see README file.\n"; 
     exit(0);
 }
 #
